import { __rest } from "tslib";
import * as React from 'react';
import { css } from '@patternfly/react-styles';
import '@patternfly/patternfly/patternfly-date-picker.css';
import styles from '@patternfly/react-styles/css/components/DatePicker/date-picker';
import buttonStyles from '@patternfly/react-styles/css/components/Button/button';
import { Locales } from '../../helpers';
import { TextInput } from "@patternfly/react-core/dist/esm/components/TextInput/TextInput";
import { Popover } from "@patternfly/react-core/dist/esm/components/Popover/Popover";
import { InputGroup } from "@patternfly/react-core/dist/esm/components/InputGroup/InputGroup";
import OutlinedCalendarAltIcon from "@patternfly/react-icons/dist/esm/icons/outlined-calendar-alt-icon";
import { parse, format, isValid as isNotNull } from 'date-fns';
import { CalendarMonth } from '../CalendarMonth';
export const DatePicker = (_a) => {
    var { className, isInvalid = false, minDate: minDateProp = '', maxDate: maxDateProp = '', dateFormat = 'MM/dd/yyyy', isDisabled = false, locale = Locales.enUS, placeholder = 'MM/dd/yyyy', value: valueProp = '', 'aria-label': ariaLabel = 'Date picker', buttonAriaLabel = 'Toggle date picker', onChange = () => undefined, invalidFormatErrorMessage, dateOutOfRangeErrorMessage, beforeMinDateErrorMessage, afterEndDateErrorMessage, helperText } = _a, props = __rest(_a, ["className", "isInvalid", "minDate", "maxDate", "dateFormat", "isDisabled", "locale", "placeholder", "value", 'aria-label', "buttonAriaLabel", "onChange", "invalidFormatErrorMessage", "dateOutOfRangeErrorMessage", "beforeMinDateErrorMessage", "afterEndDateErrorMessage", "helperText"]);
    const myParse = (date) => parse(date, dateFormat, new Date(), { locale });
    const getDefaultValueDate = () => {
        let res = myParse(valueProp);
        if (!isNotNull(res)) {
            if (isNotNull(minDate)) {
                res = new Date(minDate);
            }
            else if (isNotNull(maxDate)) {
                res = new Date(maxDate);
            }
            else {
                res = new Date();
            }
        }
        return res;
    };
    const [invalid, setInvalid] = React.useState(isInvalid);
    const [invalidText, setInvalidText] = React.useState('');
    const [value, setValue] = React.useState(valueProp);
    const [minDate, setMinDate] = React.useState(myParse(minDateProp));
    const [maxDate, setMaxDate] = React.useState(myParse(maxDateProp));
    const [valueDate, setValueDate] = React.useState(getDefaultValueDate());
    const [popoverOpen, setPopoverOpen] = React.useState(false);
    const [selectOpen, setSelectOpen] = React.useState(false);
    const buttonRef = React.useRef();
    React.useEffect(() => {
        setValueDate(getDefaultValueDate());
    }, [valueProp]);
    React.useEffect(() => {
        setMinDate(myParse(minDateProp));
    }, [minDateProp]);
    React.useEffect(() => {
        setMaxDate(myParse(maxDateProp));
    }, [maxDateProp]);
    const rangeValidator = (date, setText) => {
        let isValid = true;
        if (!isNotNull(date)) {
            isValid = false;
            if (setText) {
                setInvalidText(invalidFormatErrorMessage || `Please use format: ${dateFormat}.`);
            }
        }
        else if (isNotNull(minDate) && isNotNull(maxDate)) {
            if (date < minDate || date > maxDate) {
                isValid = false;
                if (setText) {
                    setInvalidText(dateOutOfRangeErrorMessage || `The date is outside the allowable range.`);
                }
            }
        }
        else if (isNotNull(minDate) && date < minDate) {
            isValid = false;
            if (setText) {
                setInvalidText(beforeMinDateErrorMessage || `Date is before the allowable range.`);
            }
        }
        else if (isNotNull(maxDate) && date > maxDate) {
            isValid = false;
            if (setText) {
                setInvalidText(afterEndDateErrorMessage || `Date is after the allowable range.`);
            }
        }
        if (setText) {
            setInvalid(!isValid);
        }
        return isValid;
    };
    const onTextInput = (value) => {
        setValue(value);
        const newValueDate = myParse(value);
        if (isNotNull(newValueDate)) {
            setValueDate(newValueDate);
        }
        rangeValidator(newValueDate, true);
    };
    const onDateClick = (valueDate) => {
        const newValue = format(valueDate, dateFormat, { locale });
        setValue(newValue);
        setValueDate(valueDate);
        if (rangeValidator(valueDate, true)) {
            onChange(newValue, valueDate);
            setPopoverOpen(false);
        }
    };
    return (React.createElement("div", Object.assign({ className: css(styles.datePicker, className) }, props),
        React.createElement(Popover, { position: "bottom", bodyContent: React.createElement(CalendarMonth, { date: valueDate, onChange: onDateClick, locale: locale, validators: [date => rangeValidator(date, false)], onSelectToggle: open => setSelectOpen(open) }), showClose: false, isVisible: popoverOpen, shouldClose: (_1, _2, event) => {
                event = event;
                // Let the select menu close
                if (event.keyCode && event.keyCode === 27 && selectOpen) {
                    return false;
                }
                // Let our button handle toggling
                if (buttonRef.current && buttonRef.current.contains(event.target)) {
                    return false;
                }
                setPopoverOpen(false);
                return true;
            }, withFocusTrap: true, hasNoPadding: true, hasAutoWidth: true },
            React.createElement(InputGroup, null,
                React.createElement(TextInput, { isDisabled: isDisabled, "aria-label": ariaLabel, placeholder: placeholder, validated: invalid ? 'error' : 'default', value: value, onChange: onTextInput }),
                React.createElement("button", { ref: buttonRef, className: css(buttonStyles.button, buttonStyles.modifiers.control), "aria-label": buttonAriaLabel, onClick: () => setPopoverOpen(!popoverOpen) },
                    React.createElement(OutlinedCalendarAltIcon, null)))),
        helperText && React.createElement("div", { className: styles.datePickerHelperText }, helperText),
        invalid && React.createElement("div", { className: css(styles.datePickerHelperText, styles.modifiers.error) }, invalidText)));
};
DatePicker.displayName = 'DatePicker';
//# sourceMappingURL=DatePicker.js.map