import * as React from 'react';
import '@patternfly/patternfly/patternfly-date-picker.css';
import { Locale } from '../../helpers';
export interface DatePickerProps extends Omit<React.HTMLProps<HTMLInputElement>, 'onChange' | 'onFocus' | 'onBlur' | 'disabled' | 'ref'> {
    /** Additional classes added to the date time picker. */
    className?: string;
    /** Flag indicating whether the value of the date picker is invalid. */
    isInvalid?: boolean;
    /** Accessible label for the date picker */
    'aria-label'?: string;
    /** The minimum date that a user can start picking from. */
    minDate?: string;
    /** The maximum date that a user can pick to. */
    maxDate?: string;
    /** The case sensitive date format according to date-fns */
    dateFormat?: string;
    /** Flag indicating the date picker is disabled*/
    isDisabled?: boolean;
    /** Specify the locale of the date. */
    locale?: Locale;
    /** String to display in the empty date picker field as a hint for the expected date format */
    placeholder?: string;
    /** A date string. Defaults to the current date. */
    value?: string;
    /** Error message to display when the date is provided in an invalid format. */
    invalidFormatErrorMessage?: string;
    /** Error message to display when the date is provided in outside the valid date range. */
    dateOutOfRangeErrorMessage?: string;
    /** Error message to display when the date is provided before the provided minDate. */
    beforeMinDateErrorMessage?: string;
    /** Error message to display when the date is provided after the provided maxDate. */
    afterEndDateErrorMessage?: string;
    /** Callback called every time the input value changes */
    onChange?: (value: string, date?: Date) => void;
    /** Text for label */
    helperText?: React.ReactNode;
    /** Aria label for the button */
    buttonAriaLabel?: string;
}
export declare const DatePicker: React.FunctionComponent<DatePickerProps>;
//# sourceMappingURL=DatePicker.d.ts.map