"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DatePicker = void 0;
const tslib_1 = require("tslib");
const React = tslib_1.__importStar(require("react"));
const react_styles_1 = require("@patternfly/react-styles");
require("@patternfly/patternfly/patternfly-date-picker.css");
const date_picker_1 = tslib_1.__importDefault(require("@patternfly/react-styles/css/components/DatePicker/date-picker"));
const button_1 = tslib_1.__importDefault(require("@patternfly/react-styles/css/components/Button/button"));
const helpers_1 = require("../../helpers");
const TextInput_1 = require("@patternfly/react-core/dist/js/components/TextInput/TextInput");
const Popover_1 = require("@patternfly/react-core/dist/js/components/Popover/Popover");
const InputGroup_1 = require("@patternfly/react-core/dist/js/components/InputGroup/InputGroup");
const outlined_calendar_alt_icon_1 = tslib_1.__importDefault(require("@patternfly/react-icons/dist/js/icons/outlined-calendar-alt-icon"));
const date_fns_1 = require("date-fns");
const CalendarMonth_1 = require("../CalendarMonth");
exports.DatePicker = (_a) => {
    var { className, isInvalid = false, minDate: minDateProp = '', maxDate: maxDateProp = '', dateFormat = 'MM/dd/yyyy', isDisabled = false, locale = helpers_1.Locales.enUS, placeholder = 'MM/dd/yyyy', value: valueProp = '', 'aria-label': ariaLabel = 'Date picker', buttonAriaLabel = 'Toggle date picker', onChange = () => undefined, invalidFormatErrorMessage, dateOutOfRangeErrorMessage, beforeMinDateErrorMessage, afterEndDateErrorMessage, helperText } = _a, props = tslib_1.__rest(_a, ["className", "isInvalid", "minDate", "maxDate", "dateFormat", "isDisabled", "locale", "placeholder", "value", 'aria-label', "buttonAriaLabel", "onChange", "invalidFormatErrorMessage", "dateOutOfRangeErrorMessage", "beforeMinDateErrorMessage", "afterEndDateErrorMessage", "helperText"]);
    const myParse = (date) => date_fns_1.parse(date, dateFormat, new Date(), { locale });
    const getDefaultValueDate = () => {
        let res = myParse(valueProp);
        if (!date_fns_1.isValid(res)) {
            if (date_fns_1.isValid(minDate)) {
                res = new Date(minDate);
            }
            else if (date_fns_1.isValid(maxDate)) {
                res = new Date(maxDate);
            }
            else {
                res = new Date();
            }
        }
        return res;
    };
    const [invalid, setInvalid] = React.useState(isInvalid);
    const [invalidText, setInvalidText] = React.useState('');
    const [value, setValue] = React.useState(valueProp);
    const [minDate, setMinDate] = React.useState(myParse(minDateProp));
    const [maxDate, setMaxDate] = React.useState(myParse(maxDateProp));
    const [valueDate, setValueDate] = React.useState(getDefaultValueDate());
    const [popoverOpen, setPopoverOpen] = React.useState(false);
    const [selectOpen, setSelectOpen] = React.useState(false);
    const buttonRef = React.useRef();
    React.useEffect(() => {
        setValueDate(getDefaultValueDate());
    }, [valueProp]);
    React.useEffect(() => {
        setMinDate(myParse(minDateProp));
    }, [minDateProp]);
    React.useEffect(() => {
        setMaxDate(myParse(maxDateProp));
    }, [maxDateProp]);
    const rangeValidator = (date, setText) => {
        let isValid = true;
        if (!date_fns_1.isValid(date)) {
            isValid = false;
            if (setText) {
                setInvalidText(invalidFormatErrorMessage || `Please use format: ${dateFormat}.`);
            }
        }
        else if (date_fns_1.isValid(minDate) && date_fns_1.isValid(maxDate)) {
            if (date < minDate || date > maxDate) {
                isValid = false;
                if (setText) {
                    setInvalidText(dateOutOfRangeErrorMessage || `The date is outside the allowable range.`);
                }
            }
        }
        else if (date_fns_1.isValid(minDate) && date < minDate) {
            isValid = false;
            if (setText) {
                setInvalidText(beforeMinDateErrorMessage || `Date is before the allowable range.`);
            }
        }
        else if (date_fns_1.isValid(maxDate) && date > maxDate) {
            isValid = false;
            if (setText) {
                setInvalidText(afterEndDateErrorMessage || `Date is after the allowable range.`);
            }
        }
        if (setText) {
            setInvalid(!isValid);
        }
        return isValid;
    };
    const onTextInput = (value) => {
        setValue(value);
        const newValueDate = myParse(value);
        if (date_fns_1.isValid(newValueDate)) {
            setValueDate(newValueDate);
        }
        rangeValidator(newValueDate, true);
    };
    const onDateClick = (valueDate) => {
        const newValue = date_fns_1.format(valueDate, dateFormat, { locale });
        setValue(newValue);
        setValueDate(valueDate);
        if (rangeValidator(valueDate, true)) {
            onChange(newValue, valueDate);
            setPopoverOpen(false);
        }
    };
    return (React.createElement("div", Object.assign({ className: react_styles_1.css(date_picker_1.default.datePicker, className) }, props),
        React.createElement(Popover_1.Popover, { position: "bottom", bodyContent: React.createElement(CalendarMonth_1.CalendarMonth, { date: valueDate, onChange: onDateClick, locale: locale, validators: [date => rangeValidator(date, false)], onSelectToggle: open => setSelectOpen(open) }), showClose: false, isVisible: popoverOpen, shouldClose: (_1, _2, event) => {
                event = event;
                // Let the select menu close
                if (event.keyCode && event.keyCode === 27 && selectOpen) {
                    return false;
                }
                // Let our button handle toggling
                if (buttonRef.current && buttonRef.current.contains(event.target)) {
                    return false;
                }
                setPopoverOpen(false);
                return true;
            }, withFocusTrap: true, hasNoPadding: true, hasAutoWidth: true },
            React.createElement(InputGroup_1.InputGroup, null,
                React.createElement(TextInput_1.TextInput, { isDisabled: isDisabled, "aria-label": ariaLabel, placeholder: placeholder, validated: invalid ? 'error' : 'default', value: value, onChange: onTextInput }),
                React.createElement("button", { ref: buttonRef, className: react_styles_1.css(button_1.default.button, button_1.default.modifiers.control), "aria-label": buttonAriaLabel, onClick: () => setPopoverOpen(!popoverOpen) },
                    React.createElement(outlined_calendar_alt_icon_1.default, null)))),
        helperText && React.createElement("div", { className: date_picker_1.default.datePickerHelperText }, helperText),
        invalid && React.createElement("div", { className: react_styles_1.css(date_picker_1.default.datePickerHelperText, date_picker_1.default.modifiers.error) }, invalidText)));
};
exports.DatePicker.displayName = 'DatePicker';
//# sourceMappingURL=DatePicker.js.map